==> quick-comments-0.5.3.zip: quick-comments/js/quick-comments-0.5.3.js <==
/**
 * Quick Comments for WordPress
 * Post comments quickly without leaving or refreshing the page.
 * @name quick-comments-0.5.3.js
 * @author wokamoto - http://dogmap.jp
 * @version 0.5.3
 * @date September 25, 2008
 * @copyright (c) 2008 wokamoto (dogmap.jp)
 * @license  Released under the GPL license (http://www.gnu.org/copyleft/gpl.html)
 * @requires jQuery v1.2.3 or later and jQuery.blockUI v2.08 or later and jQuery.ScrollTo V1.4 or later
 */

jQuery((function(jQuery){
  var qc_opt = jQuery.extend({
    form:'form#commentform'
   ,list:'ol.commentlist:first'
   ,requireNameEmail:false
   ,errMsgNameEmail:'Error: please fill the required fields (name, email).'
   ,errMsgCommentNone:'Error: please type a comment.'
   ,errMsgEmail:'Error: please enter a valid email address.'
   ,message:'wait...'
   ,message2:'loading...'
   ,loader:'ajax-loader.gif'
   ,messageCSS:{border:'1px solid #8C8C8C', font:'normal 12px Arial'}
   ,overlayCSS:{backgroundColor:'#FFF', opacity:'0.6'}
   ,effect:0
   ,speed:'fast'
   ,update:'/wp-content/plugins/quick-comments/quick-comments.php'
   ,editReturn:'#edit-comment-%ID%'
   ,editOffset: -50
   }, quickCommentsL10n);
  var flg_ie  = jQuery.browser.msie;
  var flg_ie6 = flg_ie && jQuery.browser.version < "7.0";

  // get comment form
  var form = jQuery(qc_opt.form);
  var form_css = {position: form.css('position')};

  // get comment list
  var list = jQuery(qc_opt.list);
  var list_css = {zoom: list.css('zoom')};

  var url_insert = form.attr('action');
  var url_update = qc_opt.update;

  var msg_template = '<div style="margin:0 auto;padding:0 1em 0;"><p style="margin:1.5em 0;white-space: nowrap;"><img src="' + qc_opt.loader + '" alt="loading" style="margin-right:.25em;" />%MESSAGE%</p></div>';

  var default_comment = jQuery('textarea[name^=comment]', form).val();
  default_comment = (typeof default_comment == 'undefined' ? '' : default_comment);

  // Get Comment Data
  var get_comment = function(){
    jQuery.scrollTo(qc_opt.form, 1000, {offset:qc_opt.editOffset});
    form.block({
      message: msg_template.replace('%MESSAGE%', qc_opt.message2)
     ,css: qc_opt.messageCSS
     ,overlayCSS: qc_opt.overlayCSS
    });
    var json_url = url_update
                 + '?json'
                 + '&comment_ID=' + jQuery(this).attr('id').replace(/^[^\d]+/, '');
    jQuery.getJSON(json_url, function(json){
      if (json.status) {
        if (jQuery('input[name^=author]',form).size() > 0) jQuery('input[name^=author]',form).val(json.author)[0].disabled = true;
        if (jQuery('input[name^=email]', form).size() > 0) jQuery('input[name^=email]', form).val(json.email)[0].disabled  = true;
        if (jQuery('input[name^=url]',   form).size() > 0) jQuery('input[name^=url]',   form).val(json.url)[0].disabled    = true;
        jQuery('textarea[name^=comment]',form).val(json.content);
        default_comment = json.content;

        if (jQuery('input#comment_ID').size() > 0) {
          jQuery('input#comment_ID').val(json.id);
        } else {
          form.append(jQuery('<input type="hidden" id="comment_ID" name="comment_ID" value="' + json.id + '" />'));
        }
        if (jQuery('input#datetime').size() > 0) {
          jQuery('input#datetime').val(json.datetime);
        } else {
          form.append(jQuery('<input type="hidden" id="datetime" name="datetime" value="' + json.datetime + '" />'));
        }
        if (jQuery('input#update').size() > 0) {
          jQuery('input#update').val('1');
        } else {
          form.append(jQuery('<input type="hidden" id="update" name="update" value="1" />'));
        }

      } else {
        alert(json.message);
      }
      form.unblock();
    });
    return false;
  }
  jQuery('a.edit-comment', list).each(function(){
    jQuery(this).unbind('click').click(get_comment);
  });

  // success
  var successCallback = function(responseText) {
    form.unblock();
    if (flg_ie6) {jQuery('legend', form).hide();}

    // Edited comment ID
    var edit_commentID = (jQuery('input#comment_ID').size() > 0 ? qc_opt.editReturn.replace('%ID%', jQuery('input#comment_ID').val()) : false);

    // Add comment list
    var list_id = (qc_opt.list).replace(/^.*[#\.]/, '').replace(/:.*$/, '');
    if (list.size() <= 0) {
      var element = (qc_opt.list).replace(/^([^#\.].*)[#\.].*$/, '$1');
      list = jQuery('<' + element + ' ' + ((/^#/).test(qc_opt.list) ? 'id' : 'class') + '="' + list_id + '"></' + element + '>');
      jQuery(qc_opt.form).prepend(list);
    }
    var body_html = responseText.replace(/[\r\n\t]/g, '').replace(/^.*<body ?[^>]*>(.*)<\/body>.*$/i, '$1');
    var comments  = jQuery(qc_opt.list, jQuery(body_html)).children();
    jQuery('a.edit-comment', comments).each(function(){
      jQuery(this).unbind('click').click(get_comment);
    });

    if (comments.length > 0) {
      if (jQuery('input#update', form).size() > 0 ) {
        // Comment Update
        list.animate({opacity:'hide'}, qc_opt.speed, function(){
          jQuery(this)
          .empty()
          .append(comments)
          .animate({opacity:'show'}, qc_opt.speed, function(){
            if (flg_ie)  {list.css(list_css);}
            if (flg_ie6) {form.css(form_css); jQuery('legend', form).show();}
            if (edit_commentID != false) {jQuery.scrollTo(edit_commentID, 1000, {offset:qc_opt.editOffset});}
          });
        });
      } else {
        // Comment Insert
        switch (qc_opt.effect) {
         case 1:
          comments = jQuery(jQuery.extend(comments.hide().get(), list.children().get()));
          list
          .empty()
          .append(comments)
          .children(':hidden').slideDown(qc_opt.speed, function(){
            if (flg_ie)  {list.css(list_css);}
            if (flg_ie6) {form.css(form_css); jQuery('legend', form).show();}
            if (edit_commentID != false) {jQuery.scrollTo(edit_commentID, 1000, {offset:qc_opt.editOffset});}
          });
          break;
         case 2:
          comments = jQuery(jQuery.extend(comments.hide().get(), list.children().get()));
          list
          .empty()
          .append(comments)
          .children(':hidden').fadeIn(qc_opt.speed, function(){
            if (flg_ie)  {list.css(list_css);}
            if (flg_ie6) {form.css(form_css); jQuery('legend', form).show();}
            if (edit_commentID != false) {jQuery.scrollTo(edit_commentID, 1000, {offset:qc_opt.editOffset});}
          });
          break;
         default:
          list.animate({opacity:'hide'}, qc_opt.speed, function(){
            jQuery(this)
            .empty()
            .append(comments)
            .animate({opacity:'show'}, qc_opt.speed, function(){
              if (flg_ie)  {list.css(list_css);}
              if (flg_ie6) {form.css(form_css); jQuery('legend', form).show();}
              if (edit_commentID != false) {jQuery.scrollTo(edit_commentID, 1000, {offset:qc_opt.editOffset});}
            });
          });
          break;
        }
      }
      jQuery('textarea[name^=comment]', form).val(''); // Reset comment

    } else {
      alert(responseText.replace(/[\r\n\t]/g, '').replace(/^.*<body ?[^>]*>(.*)<\/body>.*$/i, '$1').replace(/<[^>]*>/, ''));
    }

    jQuery('input#comment_ID').remove();
    jQuery('input#datetime').remove();
    jQuery('input#update').remove();
    jQuery('input#quick-comments').remove();
  };

  // error
  var errorCallback = function(httpRequest, status, e) {
    form.unblock();
    if (flg_ie6) {jQuery('legend', form).hide();}
    alert(httpRequest.responseText.replace(/[\r\n\t]/g, '').replace(/^.*<p>(.*?)<\/p>.*$/i, '$1'));
    if (flg_ie6) {form.css(form_css); jQuery('legend', form).show();}
  };

  // comment form AJAX submit
  form.submit(function(){
    if (jQuery('input#quick-comments', jQuery(this)).size() <= 0) jQuery(this).append('<input type="hidden" name="quick-comments" id="quick-comments" value="1" />');

    var author_name  = jQuery('input[name^=author]', jQuery(this)).val();
    var author_email = jQuery('input[name^=email]', jQuery(this)).val();
    var comment_text = jQuery('textarea[name^=comment]', jQuery(this)).val();

    author_name  = (typeof author_name == 'undefined'  ? '' : author_name);
    author_email = (typeof author_email == 'undefined' ? '' : author_email);
    comment_text = (typeof comment_text == 'undefined' ? '' : comment_text);

    // require Name & Email
    if (qc_opt.requireNameEmail && (author_name == "" || author_email  == "")) {
      alert (qc_opt.errMsgNameEmail);
      return false;
    }

    // valid Email ?
    if (author_email != "" && !(/^([a-z0-9+_]|\-|\.)+@(([a-z0-9_]|\-)+\.)+[a-z]{2,6}$/).test(author_email)) {
      alert (qc_opt.errMsgEmail);
      return false;
    }

    // type Comment ?
    if (comment_text == "" || comment_text == default_comment) {
      alert (qc_opt.errMsgCommentNone);
      return false;
    }

    jQuery('input',jQuery(this)).each(function(){this.disabled = false;});
    var url = ( jQuery('input#update').size() > 0 ? url_update : url_insert );
    var param = jQuery('input, textarea', jQuery(this)).serialize();

    // Form Block
    jQuery(this).block({
      message: msg_template.replace('%MESSAGE%', qc_opt.message)
     ,css: qc_opt.messageCSS
     ,overlayCSS: qc_opt.overlayCSS
    })

    // Post Comment
    jQuery.ajax({
      type:    "POST"
     ,cache:   false
     ,url:     url
     ,data:    param
     ,success: successCallback
     ,error:   errorCallback
    });

    return false;
   });

})(jQuery));

==> quick-comments-0.6.0.zip: quick-comments/js/quick-comments-0.6.0.js <==
/**
 * Quick Comments for WordPress
 * Post comments quickly without leaving or refreshing the page.
 * @name quick-comments-0.6.0.js
 * @author wokamoto - http://dogmap.jp
 * @version 0.6.0
 * @date November 14, 2008
 * @copyright (c) 2008 wokamoto (dogmap.jp)
 * @license  Released under the GPL license (http://www.gnu.org/copyleft/gpl.html)
 * @requires jQuery v1.2.3 or later and jQuery.blockUI v2.08 or later and jQuery.ScrollTo V1.4 or later
 */

if (typeof jQuery !== 'undefined') {

jQuery((function(jQuery){
  var qc_opt = jQuery.extend({
    form:'form#commentform'
   ,list:'ol.commentlist:first'
   ,requireNameEmail:false
   ,errMsgNameEmail:'Error: please fill the required fields (name, email).'
   ,errMsgCommentNone:'Error: please type a comment.'
   ,errMsgEmail:'Error: please enter a valid email address.'
   ,message:'wait...'
   ,message2:'loading...'
   ,loader:'ajax-loader.gif'
   ,messageCSS:{border:'1px solid #8C8C8C', font:'normal 12px Arial'}
   ,overlayCSS:{backgroundColor:'#FFF', opacity:'0.6'}
   ,effect:0
   ,speed:'fast'
   ,update:'/wp-content/plugins/quick-comments/quick-comments.php'
   ,editReturn:'#edit-comment-%ID%'
   ,editOffset: -50
   ,editButtonLabel:'Update Comment'
   ,editDisabled:{author:true, email:true, url:true}
   }, quickCommentsL10n);
  var flg_ie  = jQuery.browser.msie;
  var flg_ie6 = flg_ie && jQuery.browser.version < "7.0";

  // get comment form
  var form = jQuery(qc_opt.form);
  var form_css = {position: form.css('position')};

  // get comment list
  var list = jQuery(qc_opt.list);
  var list_css = {zoom: list.css('zoom')};

  var url_insert = form.attr('action');
  var url_update = qc_opt.update;

  var msg_template = '<div style="margin:0 auto;padding:0 1em 0;"><p style="margin:1.5em 0;white-space: nowrap;"><img src="' + qc_opt.loader + '" alt="loading" style="margin-right:.25em;" />%MESSAGE%</p></div>';

  var default_comment = jQuery('textarea[name^=comment]', form).val();
  default_comment = (typeof default_comment === 'undefined' ? '' : default_comment);

  var commentButtonLabel = jQuery('#submit', form).val();

  // Get Comment Data
  var get_comment = function(){
    commentButtonLabel = jQuery('#submit', form).val();
    jQuery.scrollTo(qc_opt.form, 1000, {offset:qc_opt.editOffset});
    form.block({
      message: msg_template.replace('%MESSAGE%', qc_opt.message2)
     ,css: qc_opt.messageCSS
     ,overlayCSS: qc_opt.overlayCSS
    });
    var json_url = url_update
                 + '?json'
                 + '&comment_ID=' + jQuery(this).attr('id').replace(/^[^\d]+/, '');
    jQuery.getJSON(json_url, function(json){
      if (json.status) {
        jQuery('input[type^=text]').each(function(){this.disabled = true;});
        var author = jQuery('input[name^=author]',form)
          , email = jQuery('input[name^=email]', form)
          , url = jQuery('input[name^=url]', form);
        if (author.length > 0)
          author.val(json.author)[0].disabled = qc_opt.editDisabled.author;
        if (email.length > 0)
          email.val(json.email)[0].disabled = qc_opt.editDisabled.email;
        if (url.length > 0)
          url.val(json.url)[0].disabled = qc_opt.editDisabled.url;
        jQuery('textarea[name^=comment]',form).val(json.content);
        //default_comment = json.content;

        if (jQuery('#comment_ID').length > 0) {
          jQuery('#comment_ID').val(json.id);
        } else {
          form.append(jQuery('<input type="hidden" id="comment_ID" name="comment_ID" value="' + json.id + '" />'));
        }
        if (jQuery('#datetime').length > 0) {
          jQuery('#datetime').val(json.datetime);
        } else {
          form.append(jQuery('<input type="hidden" id="datetime" name="datetime" value="' + json.datetime + '" />'));
        }
        if (jQuery('#update').length > 0) {
          jQuery('#update').val('1');
        } else {
          form.append(jQuery('<input type="hidden" id="update" name="update" value="1" />'));
        }

      } else {
        alert(json.message);
      }
      jQuery('#submit', form).val(qc_opt.editButtonLabel);
      form.unblock();
    });
    return false;
  }
  jQuery('a.edit-comment', list).each(function(){
    jQuery(this).unbind('click').click(get_comment);
  });

  // success
  var successCallback = function(responseText) {
    form.unblock();
    if (flg_ie6) {jQuery('legend', form).hide();}

    // Edited comment ID
    var edit_commentID = (jQuery('#comment_ID').length > 0 ? qc_opt.editReturn.replace('%ID%', jQuery('#comment_ID').val()) : false);

    // Add comment list
    var list_id = (qc_opt.list).replace(/^.*[#\.]/, '').replace(/:.*$/, '');
    if (list.size() <= 0) {
      var element = (qc_opt.list).replace(/^([^#\.].*)[#\.].*$/, '$1');
      list = jQuery('<' + element + ' ' + ((/^#/).test(qc_opt.list) ? 'id' : 'class') + '="' + list_id + '"></' + element + '>');
      jQuery(qc_opt.form).prepend(list);
    }
    var body_html = responseText.replace(/[\r\n\t]/g, '').replace(/^.*<body ?[^>]*>(.*)<\/body>.*$/i, '$1');
    var comments  = jQuery(qc_opt.list, jQuery(body_html)).children();
    jQuery('a.edit-comment', comments).each(function(){
      jQuery(this).unbind('click').click(get_comment);
    });

    if (comments.length > 0) {
      if (jQuery('input#update', form).size() > 0 ) {
        // Comment Update
        list.animate({opacity:'hide'}, qc_opt.speed, function(){
          jQuery(this)
          .empty()
          .append(comments)
          .animate({opacity:'show'}, qc_opt.speed, function(){
            if (flg_ie)  {list.css(list_css);}
            if (flg_ie6) {form.css(form_css); jQuery('legend', form).show();}
            if (edit_commentID !== false) {jQuery.scrollTo(edit_commentID, 1000, {offset:qc_opt.editOffset});}
          });
        });
      } else {
        // Comment Insert
        switch (qc_opt.effect) {
         case 1:
          comments = jQuery(jQuery.extend(comments.hide().get(), list.children().get()));
          list
          .empty()
          .append(comments)
          .children(':hidden').slideDown(qc_opt.speed, function(){
            if (flg_ie)  {list.css(list_css);}
            if (flg_ie6) {form.css(form_css); jQuery('legend', form).show();}
            if (edit_commentID !== false) {jQuery.scrollTo(edit_commentID, 1000, {offset:qc_opt.editOffset});}
          });
          break;
         case 2:
          comments = jQuery(jQuery.extend(comments.hide().get(), list.children().get()));
          list
          .empty()
          .append(comments)
          .children(':hidden').fadeIn(qc_opt.speed, function(){
            if (flg_ie)  {list.css(list_css);}
            if (flg_ie6) {form.css(form_css); jQuery('legend', form).show();}
            if (edit_commentID !== false) {jQuery.scrollTo(edit_commentID, 1000, {offset:qc_opt.editOffset});}
          });
          break;
         default:
          list.animate({opacity:'hide'}, qc_opt.speed, function(){
            jQuery(this)
            .empty()
            .append(comments)
            .animate({opacity:'show'}, qc_opt.speed, function(){
              if (flg_ie)  {list.css(list_css);}
              if (flg_ie6) {form.css(form_css); jQuery('legend', form).show();}
              if (edit_commentID !== false) {jQuery.scrollTo(edit_commentID, 1000, {offset:qc_opt.editOffset});}
            });
          });
          break;
        }
      }
      jQuery('textarea[name^=comment]', form).val(''); // Reset comment

    } else {
      alert(responseText.replace(/[\r\n\t]/g, '').replace(/^.*<body ?[^>]*>(.*)<\/body>.*$/i, '$1').replace(/<[^>]*>/, ''));
    }

    jQuery('#comment_ID').remove();
    jQuery('#datetime').remove();
    jQuery('#update').remove();
    jQuery('#quick-comments').remove();
    jQuery('#submit', form).val(commentButtonLabel);
  };

  // error
  var errorCallback = function(httpRequest, status, e) {
    form.unblock();
    if (flg_ie6) {jQuery('legend', form).hide();}
    alert(httpRequest.responseText.replace(/[\r\n\t]/g, '').replace(/^.*<p>(.*?)<\/p>.*$/i, '$1'));
    if (flg_ie6) {form.css(form_css); jQuery('legend', form).show();}
    jQuery('#submit', form).val(commentButtonLabel);
  };

  // comment form AJAX submit
  form.submit(function(){
    if (jQuery('#quick-comments').length <= 0) jQuery(this).append('<input type="hidden" name="quick-comments" id="quick-comments" value="1" />');

    var author_name  = jQuery('input[name^=author]', jQuery(this)).val();
    var author_email = jQuery('input[name^=email]', jQuery(this)).val();
    var comment_text = jQuery('textarea[name^=comment]', jQuery(this)).val();

    author_name  = (typeof author_name  === 'undefined' ? '' : author_name);
    author_email = (typeof author_email === 'undefined' ? '' : author_email);
    comment_text = (typeof comment_text === 'undefined' ? '' : comment_text);

    // require Name & Email
    if (qc_opt.requireNameEmail && (author_name === '' || author_email === '')) {
      alert (qc_opt.errMsgNameEmail);
      return false;
    }

    // valid Email ?
    if (author_email !== "" && !(/^([a-z0-9+_]|\-|\.)+@(([a-z0-9_]|\-)+\.)+[a-z]{2,6}$/).test(author_email)) {
      alert (qc_opt.errMsgEmail);
      return false;
    }

    // type Comment ?
    if (comment_text === "" || comment_text === default_comment) {
      alert (qc_opt.errMsgCommentNone);
      return false;
    }

    jQuery('input',jQuery(this)).each(function(){this.disabled = false;});
    var url = ( jQuery('input#update').length > 0 ? url_update : url_insert );
    var param = jQuery('input, textarea', jQuery(this)).serialize();

    // Form Block
    jQuery(this).block({
      message: msg_template.replace('%MESSAGE%', qc_opt.message)
     ,css: qc_opt.messageCSS
     ,overlayCSS: qc_opt.overlayCSS
    })

    // Post Comment
    jQuery.ajax({
      type:    "POST"
     ,cache:   false
     ,url:     url
     ,data:    param
     ,success: successCallback
     ,error:   errorCallback
    });

    return false;
   });

})(jQuery));

};
